/*
 * gaim
 *
 * Copyright (C) 1998-1999, Mark Spencer <markster@marko.net>
 *
 * osd.c: On-screen display plugin for Gaim.
 * Copyright (C) 2001 Chris Sperandio <csperandio@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
/* (cvs $Id: conv.c,v 1.7 2004/01/05 05:10:27 deryni9 Exp $) */

#include "gaimosd.h"

/* TODO:
	- need to add osd icon in osd_conv_new()
*/

#if BUILD_OSD_CONVS
static GList *Osd_convs = NULL;
static GList *Osd_chats = NULL;

osd_conv_t *
osd_conv_new(GaimConversation *conv)
{
	GList **list;
	osd_conv_t *oc;
	gboolean add_icon;

	oc = g_new0(osd_conv_t,1);
	if (!oc) return NULL;

	if (gaim_conversation_get_type(conv) == GAIM_CONV_CHAT) {
		list = &Osd_chats;
		oc->display = gaim_prefs_get_int(GAIMOSD_PREFS "/chat/display_def");
		add_icon = gaim_prefs_get_bool(GAIMOSD_PREFS "/chat/toolbar");
	} else {
		list = &Osd_convs;
		oc->display = gaim_prefs_get_int(GAIMOSD_PREFS "/conv/display_def");
		add_icon = gaim_prefs_get_bool(GAIMOSD_PREFS "/conv/toolbar");
	}
	oc->conv = conv;

	/* add osd icon */
	if (add_icon) {
	}

	*list = g_list_append(*list,oc);
	return oc;
}

void
osd_conv_rebuild(void)
{
	GaimConversation *conv;
	GList *list = gaim_get_conversations();

	while (list) {
		conv = (GaimConversation *) list->data;
		osd_conv_new(conv);
		list = list->next;
	}
}

void
osd_conv_free(gpointer data, gpointer p)
{
	osd_conv_t *oc = (osd_conv_t *)data;

	/* remove OSD icon */

	g_free(oc);
}

void
osd_conv_free_all(void)
{
	GList *tmp;

	tmp = Osd_convs;
	Osd_convs = NULL;
	g_list_foreach(tmp, osd_conv_free, NULL);
	g_list_free(tmp);

	tmp = Osd_chats;
	Osd_chats = NULL;
	g_list_foreach(tmp, osd_conv_free, NULL);
	g_list_free(tmp);
}

osd_conv_t *
osd_conv_find(GaimConversation *conv)
{
	GList *search;
	osd_conv_t *oc = NULL;
	gboolean found = FALSE;

	if (!conv) return NULL;
	search = (gaim_conversation_get_type(conv) == GAIM_CONV_CHAT) ? Osd_chats : Osd_convs;

	while (search) {
		oc = (osd_conv_t *) search->data;
		if (oc->conv == conv) {
			found = TRUE;
			break;
		}
		search = search->next;
	}
	return (found) ? oc : NULL;
}

void
osd_conv_delete(GaimConversation *conv)
{
	osd_conv_t *oc;
	GList **list, *search;

	list = (gaim_conversation_get_type(conv) == GAIM_CONV_CHAT) ? &Osd_chats : &Osd_convs;
	search = *list;

	while (search) {
		oc = (osd_conv_t *) search->data;
		if (oc->conv == conv) {
			*list = g_list_delete_link(*list, search);
			osd_conv_free(oc, NULL);
			break;
		}
		search = search->next;
	}
}

#endif /* BUILD_OSD_CONVS */
